@@ -1,6 +1,7 @@
 """Main entry point for the YouTrack CLI."""
 
 import asyncio
+from pathlib import Path
 from typing import Optional, cast
 
 import click
@@ -376,83 +377,6 @@ def groups_create(ctx: click.Context, name: str, description: Optional[str]) ->
     asyncio.run(run_create_group())
 
 
-@main.group()
-def settings() -> None:
-    """Manage global YouTrack settings.
-
-    This is a flatter alternative to 'yt admin global-settings'.
-    You can also use 'yt admin global-settings' for the same functionality.
-    """
-    pass
-
-
-@settings.command(name="get")
-@click.option("--name", "-n", help="Specific setting name to retrieve")
-@click.pass_context
-def settings_get(ctx: click.Context, name: Optional[str]) -> None:
-    """Get global settings."""
-    auth_manager = AuthManager(ctx.obj.get("config"))
-    admin_manager = AdminManager(auth_manager)
-    console = get_console()
-
-    async def run_get_settings() -> None:
-        result = await admin_manager.get_global_settings(name)
-
-        if result["status"] == "error":
-            console.print(f"[red]Error:[/red] {result['message']}")
-            return
-
-        settings = result["data"]
-        if name:
-            admin_manager.display_global_settings(settings)
-        else:
-            admin_manager.display_global_settings(settings)
-
-    asyncio.run(run_get_settings())
-
-
-@settings.command(name="set")
-@click.argument("name")
-@click.argument("value")
-@click.pass_context
-def settings_set(ctx: click.Context, name: str, value: str) -> None:
-    """Set a global setting."""
-    auth_manager = AuthManager(ctx.obj.get("config"))
-    admin_manager = AdminManager(auth_manager)
-    console = get_console()
-
-    async def run_set_setting() -> None:
-        result = await admin_manager.set_global_setting(name, value)
-
-        if result["status"] == "error":
-            console.print(f"[red]Error:[/red] {result['message']}")
-            return
-
-        console.print(f"[green]Success:[/green] {result['message']}")
-
-    asyncio.run(run_set_setting())
-
-
-@settings.command(name="list")
-@click.pass_context
-def settings_list(ctx: click.Context) -> None:
-    """List all global settings."""
-    auth_manager = AuthManager(ctx.obj.get("config"))
-    admin_manager = AdminManager(auth_manager)
-    console = get_console()
-
-    async def run_list_settings() -> None:
-        result = await admin_manager.get_global_settings()
-
-        if result["status"] == "error":
-            console.print(f"[red]Error:[/red] {result['message']}")
-            return
-
-        admin_manager.display_global_settings(result["data"])
-
-    asyncio.run(run_list_settings())
-
-
 @main.command(name="audit")
 @click.option(
     "--limit",
@@ -1243,10 +1167,27 @@ def auth(ctx: click.Context) -> None:
 )
 @click.option("--token", "-t", prompt=True, hide_input=True, help="YouTrack API token")
 @click.option("--username", "-n", help="Username (optional)")
+@click.option(
+    "--cert-file",
+    type=click.Path(exists=True, readable=True, path_type=Path),
+    help="Path to SSL certificate file (.crt or .pem)",
+)
+@click.option(
+    "--ca-bundle",
+    type=click.Path(exists=True, readable=True, path_type=Path),
+    help="Path to CA bundle file",
+)
+@click.option(
+    "--verify-ssl/--no-verify-ssl",
+    default=True,
+    help="Enable/disable SSL certificate verification (default: enabled)",
+)
 @click.option(
     "--no-verify-ssl",
+    "no_verify_ssl_deprecated",
     is_flag=True,
-    help="Disable SSL certificate verification (use with caution)",
+    hidden=True,
+    help="Deprecated: Use '--no-verify-ssl' flag option instead of standalone flag",
 )
 @click.pass_context
 def login(
@@ -1254,7 +1195,10 @@ def login(
     base_url: str,
     token: str,
     username: Optional[str],
-    no_verify_ssl: bool,
+    cert_file: Optional[Path],
+    ca_bundle: Optional[Path],
+    verify_ssl: bool,
+    no_verify_ssl_deprecated: bool,
 ) -> None:
     """Authenticate with YouTrack.
 
@@ -1266,6 +1210,7 @@ def login(
     - Prompt for API token securely (hidden input)
     - Validate the connection
     - Save credentials for future use
+    - Support custom SSL certificates for self-signed or enterprise CAs
 
     Examples:
         # Interactive login (recommended)
@@ -1274,30 +1219,66 @@ def login(
         # Login with URL specified
         yt auth login --base-url https://company.youtrack.cloud
 
-        # Login with username
-        yt auth login --username john.doe
+        # Login with custom certificate
+        yt auth login --cert-file /path/to/cert.pem
+
+        # Login with CA bundle
+        yt auth login --ca-bundle /path/to/ca-bundle.crt
+
+        # Login without SSL verification (not recommended)
+        yt auth login --no-verify-ssl
     """
     console = get_console()
     auth_manager = AuthManager(ctx.obj.get("config"))
 
     console.print("🔐 Authenticating with YouTrack...", style="blue")
 
-    if no_verify_ssl:
+    # Handle deprecated --no-verify-ssl flag
+    if no_verify_ssl_deprecated:
+        verify_ssl = False
+        console.print(
+            "⚠️  The standalone --no-verify-ssl flag is deprecated. Use '--no-verify-ssl' as a boolean flag option instead.",
+            style="yellow",
+        )
+
+    # Determine SSL verification configuration
+    ssl_verify = True  # Default to True
+    if cert_file:
+        ssl_verify = str(cert_file)
+        console.print(f"🔒 Using SSL certificate: {cert_file}", style="blue")
+    elif ca_bundle:
+        ssl_verify = str(ca_bundle)
+        console.print(f"🔒 Using CA bundle: {ca_bundle}", style="blue")
+    elif not verify_ssl:
+        ssl_verify = False
         console.print("⚠️  SSL certificate verification disabled. Use with caution!", style="yellow")
 
     try:
-        # Verify credentials
-        result = asyncio.run(auth_manager.verify_credentials(base_url, token, verify_ssl=not no_verify_ssl))
+        # Verify credentials with SSL configuration
+        result = asyncio.run(auth_manager.verify_credentials(base_url, token, verify_ssl=ssl_verify))
 
         if result.status == "success":
-            # Save credentials
-            auth_manager.save_credentials(base_url, token, username, verify_ssl=not no_verify_ssl)
+            # Save credentials with certificate paths
+            auth_manager.save_credentials(
+                base_url,
+                token,
+                username,
+                verify_ssl=ssl_verify,
+                cert_file=str(cert_file) if cert_file else None,
+                ca_bundle=str(ca_bundle) if ca_bundle else None,
+            )
 
             console.print("✅ Authentication successful!", style="green")
             console.print(f"Logged in as: {result.username}", style="green")
             console.print(f"Full name: {result.full_name}", style="green")
             if result.email:
                 console.print(f"Email: {result.email}", style="green")
+
+            # Show certificate info if used
+            if cert_file:
+                console.print(f"Certificate file: {cert_file}", style="dim")
+            elif ca_bundle:
+                console.print(f"CA bundle: {ca_bundle}", style="dim")
         else:
             format_and_print_error(CommonErrors.authentication_failed(details=result.message))
             raise click.ClickException("Authentication failed")
@@ -1835,24 +1816,24 @@ def list_aliases(ctx: click.Context) -> None:
             console.print(table)
         else:
             console.print("ℹ️  No aliases found", style="yellow")
-            console.print("💡 Create an alias with: yt alias add <name> <command>", style="dim")
+            console.print("💡 Create an alias with: yt alias create <name> <command>", style="dim")
 
     except Exception as e:
         console.print(f"❌ Error listing aliases: {e}", style="red")
         raise click.ClickException("Alias list failed") from e
 
 
-@alias.command("add")
+@alias.command("create")
 @click.argument("name")
 @click.argument("command")
 @click.pass_context
-def add_alias(ctx: click.Context, name: str, command: str) -> None:
-    """Add a user-defined alias.
+def create_alias(ctx: click.Context, name: str, command: str) -> None:
+    """Create a user-defined alias.
 
     Examples:
-        yt alias add myissues "issues list --assignee me"
-        yt alias add bug "issues create --type Bug"
-        yt alias add il "issues list"
+        yt alias create myissues "issues list --assignee me"
+        yt alias create bug "issues create --type Bug"
+        yt alias create il "issues list"
     """
     console = get_console()
     config_manager = ConfigManager(ctx.obj.get("config"))
@@ -1886,11 +1867,80 @@ def add_alias(ctx: click.Context, name: str, command: str) -> None:
         raise click.ClickException("Alias creation failed") from e
 
 
-@alias.command("remove")
+# Backwards compatibility: keep 'add' as a hidden alias
+@alias.command("add", hidden=True)
+@click.argument("name")
+@click.argument("command")
+@click.pass_context
+def add_alias(ctx: click.Context, name: str, command: str) -> None:
+    """Add a user-defined alias (deprecated, use 'create' instead)."""
+    # Call the same logic as create_alias
+    console = get_console()
+    config_manager = ConfigManager(ctx.obj.get("config"))
+
+    try:
+        # Check if alias conflicts with existing command
+        main_group = ctx.find_root().command
+        if hasattr(main_group, "list_commands") and name in main_group.list_commands(ctx):
+            console.print(f"❌ Cannot create alias '{name}': conflicts with existing command", style="red")
+            return
+
+        # Check if alias conflicts with built-in alias
+        if hasattr(main_group, "aliases"):
+            aliases = cast(dict, main_group.aliases)
+            if name in aliases:
+                console.print(f"❌ Cannot create alias '{name}': conflicts with built-in alias", style="red")
+                return
+
+        # Add the alias
+        config_manager.set_alias(name, command)
+
+        # Reload aliases in the main group
+        if hasattr(main_group, "reload_user_aliases"):
+            main_group.reload_user_aliases()
+
+        console.print(f"✅ Alias '{name}' → '{command}' created successfully", style="green")
+        console.print("💡 Use 'yt alias list' to see all aliases", style="dim")
+
+    except Exception as e:
+        console.print(f"❌ Error creating alias: {e}", style="red")
+        raise click.ClickException("Alias creation failed") from e
+
+
+@alias.command("delete")
 @click.argument("name")
 @click.pass_context
-def remove_alias(ctx: click.Context, name: str) -> None:
-    """Remove a user-defined alias."""
+def delete_alias(ctx: click.Context, name: str) -> None:
+    """Delete a user-defined alias."""
+    console = get_console()
+    config_manager = ConfigManager(ctx.obj.get("config"))
+
+    try:
+        # Check if alias exists
+        if config_manager.get_alias(name) is None:
+            console.print(f"❌ Alias '{name}' not found", style="red")
+            return
+
+        # Remove the alias
+        config_manager.remove_alias(name)
+
+        # Reload aliases in the main group
+        main_group = ctx.find_root().command
+        if hasattr(main_group, "reload_user_aliases"):
+            main_group.reload_user_aliases()
+
+        console.print(f"✅ Alias '{name}' deleted successfully", style="green")
+
+    except Exception as e:
+        console.print(f"❌ Error deleting alias: {e}", style="red")
+        raise click.ClickException("Alias deletion failed") from e
+
+
+@alias.command("remove", hidden=True)
+@click.argument("name")
+@click.pass_context
+def remove_alias_deprecated(ctx: click.Context, name: str) -> None:
+    """Remove a user-defined alias (deprecated, use 'delete' instead)."""
     console = get_console()
     config_manager = ConfigManager(ctx.obj.get("config"))
 
@@ -2101,54 +2151,6 @@ def global_settings() -> None:
     pass
 
 
-@global_settings.command(name="get")
-@click.option("--name", "-n", help="Specific setting name to retrieve")
-@click.pass_context
-def get_settings(ctx: click.Context, name: Optional[str]) -> None:
-    """Get global settings."""
-    auth_manager = AuthManager(ctx.obj.get("config"))
-    admin_manager = AdminManager(auth_manager)
-    console = get_console()
-
-    async def run_get_settings() -> None:
-        result = await admin_manager.get_global_settings(name)
-
-        if result["status"] == "error":
-            console.print(f"[red]Error:[/red] {result['message']}")
-            return
-
-        settings = result["data"]
-        if name:
-            # For specific setting requests, the data should be the setting itself
-            admin_manager.display_global_settings(settings)
-        else:
-            admin_manager.display_global_settings(settings)
-
-    asyncio.run(run_get_settings())
-
-
-@global_settings.command(name="set")
-@click.argument("name")
-@click.argument("value")
-@click.pass_context
-def set_setting(ctx: click.Context, name: str, value: str) -> None:
-    """Set a global setting."""
-    auth_manager = AuthManager(ctx.obj.get("config"))
-    admin_manager = AdminManager(auth_manager)
-    console = get_console()
-
-    async def run_set_setting() -> None:
-        result = await admin_manager.set_global_setting(name, value)
-
-        if result["status"] == "error":
-            console.print(f"[red]Error:[/red] {result['message']}")
-            return
-
-        console.print(f"[green]Success:[/green] {result['message']}")
-
-    asyncio.run(run_set_setting())
-
-
 @global_settings.command(name="list")
 @click.pass_context
 def list_settings(ctx: click.Context) -> None:
@@ -2175,26 +2177,6 @@ def license() -> None:
     pass
 
 
-@license.command()
-@click.pass_context
-def show(ctx: click.Context) -> None:
-    """Display license information."""
-    auth_manager = AuthManager(ctx.obj.get("config"))
-    admin_manager = AdminManager(auth_manager)
-    console = get_console()
-
-    async def run_license_info() -> None:
-        result = await admin_manager.get_license_info()
-
-        if result["status"] == "error":
-            console.print(f"[red]Error:[/red] {result['message']}")
-            return
-
-        admin_manager.display_license_info(result["data"])
-
-    asyncio.run(run_license_info())
-
-
 @license.command()
 @click.pass_context
 def usage(ctx: click.Context) -> None:
@@ -2221,33 +2203,6 @@ def maintenance() -> None:
     pass
 
 
-@maintenance.command(name="clear-cache")
-@click.option("--force", is_flag=True, help="Skip confirmation prompt")
-@click.pass_context
-def clear_cache(ctx: click.Context, force: bool) -> None:
-    """Clear system caches."""
-    auth_manager = AuthManager(ctx.obj.get("config"))
-    admin_manager = AdminManager(auth_manager)
-    console = get_console()
-
-    if not force:
-        console.print("[yellow]Warning:[/yellow] This will clear all system caches.")
-        if not click.confirm("Continue?"):
-            console.print("Operation cancelled.")
-            return
-
-    async def run_clear_cache() -> None:
-        result = await admin_manager.clear_caches()
-
-        if result["status"] == "error":
-            console.print(f"[red]Error:[/red] {result['message']}")
-            return
-
-        console.print(f"[green]Success:[/green] {result['message']}")
-
-    asyncio.run(run_clear_cache())
-
-
 @admin.group()
 def health() -> None:
     """System health checks and diagnostics."""
@@ -2448,6 +2403,26 @@ def get_i18n(ctx: click.Context) -> None:
     asyncio.run(run_get_i18n())
 
 
+@i18n.command(name="list")
+@click.pass_context
+def list_i18n(ctx: click.Context) -> None:
+    """List available locales (same as locale list)."""
+    auth_manager = AuthManager(ctx.obj.get("config"))
+    admin_manager = AdminManager(auth_manager)
+    console = get_console()
+
+    async def run_list_i18n() -> None:
+        result = await admin_manager.get_available_locales()
+
+        if result["status"] == "error":
+            console.print(f"[red]Error:[/red] {result['message']}")
+            return
+
+        admin_manager.display_available_locales(result["data"], result.get("message"))
+
+    asyncio.run(run_list_i18n())
+
+
 @i18n.command(name="set")
 @click.option(
     "--language",
